Core Base Classes for the Light Endpoints

Dependencies:   BufferedSerial

Dependents:   mbed_mqtt_endpoint_ublox_ethernet mbed_mqtt_endpoint_ublox_cellular mbed_nsp_endpoint_ublox_cellular mbed_nsp_endpoint_ublox_ethernet ... more

Revision:
179:35e88daf2d75
Parent:
177:fa93eacedd3d
Child:
184:b73d6c976063
--- a/main.cpp	Fri Aug 29 21:41:19 2014 +0000
+++ b/main.cpp	Tue Sep 09 20:41:24 2014 +0000
@@ -42,28 +42,25 @@
  Mutex *network_mutex = NULL;
  #endif
  
- #ifdef _ENDPOINT_UBLOX_PLATFORM
-     // Serial Console Support
-     Serial pc(USBTX, USBRX);
-     
+ // Buffered Serial
+ #include "BufferedSerial.h"
+
+ // Serial Console Support
+ BufferedSerial pc(USBTX, USBRX);
+ 
+ #ifdef _ENDPOINT_UBLOX_PLATFORM    
      // LCD Support
      #include "C12832.h"
      C12832 lcd(D11, D13, D12, D7, D10);
 #endif
 
-#ifdef _ENDPOINT_NXP_PLATFORM
-     // Serial Console Support
-     Serial pc(USBTX, USBRX);
-     
+#ifdef _ENDPOINT_NXP_PLATFORM     
      // LCD Support
      #include "C12832_lcd.h"
      C12832_LCD lcd; 
 #endif
 
-#ifdef _ENDPOINT_FREEDOM_PLATFORM   
-    // Serial Console Support
-     Serial pc(USBTX, USBRX);
-     
+#ifdef _ENDPOINT_FREEDOM_PLATFORM        
      // LCD Support
      #include "C12832_lcd.h"
      C12832_LCD lcd;